@@ -982,6 +982,7 @@ def map01(df, province, parameter_x, method):
     import numpy as np
     import folium
     import pandas as pd
+    import webbrowser
 
     df = df
     df1 = df[[province, parameter_x]]
@@ -1033,8 +1034,10 @@ def map01(df, province, parameter_x, method):
         highlight=True,
     )
 
+    pdsmap.save('PDS_map.html')
+    url = 'PDS_map.html'
+    webbrowser.open(url, new=2)
     # display(pdsmap)
-    return pdsmap
 
 
 
